#!/usr/bin/env python
"""
Levox - GDPR, PII and Data Flow Compliance Tool

A tool for scanning, fixing, and reporting GDPR compliance issues in code.
"""
import sys
import os
from pathlib import Path

# Import benchmark data from benchmark module
from levox.benchmark import get_benchmark_results
from levox.meta_learning import MetaLearningEngine, SKLEARN_AVAILABLE

# Fallback benchmark data if module not available
FALLBACK_BENCHMARK_DATA = {
    "name": "DVNA (Damn Vulnerable Node.js Application)",
    "files_scanned": 133,
    "lines_scanned": 22385,
    "scan_time": 0.12,
    "issues_found": 23,
    "true_positives": 21,
    "false_positives": 2,
    "accuracy": 0.91
}

# Version and system information
VERSION = "1.5.4"  # Updated version number
BUILD_DATE = "2024-03-15"
SYSTEM_INFO = f"Python {sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}"

def get_features():
    """Get a list of Levox features."""
    features = [
        "GDPR Compliance Scanning",
        "PII Detection and Classification",
        "Data Flow Analysis",
        "AI-Assisted Remediation",
        "Detailed HTML Reports",
        "Interactive Command Line Interface",
        "AST-based Code Analysis",
        "Adaptive Meta-Learning" # New feature
    ]
    
    # Check if meta-learning is available
    try:
        features.append("Meta-Learning for Reduced False Positives")
        
        # Check if advanced meta-learning is available
        if SKLEARN_AVAILABLE:
            features.append("Advanced Semantic Analysis (with scikit-learn)")
        else:
            features.append("Basic Semantic Analysis (fallback mode)")
    except Exception:
        pass
        
    return features

def main():
    """Main function for starting the Levox CLI."""
    try:
        # First try to start with the interactive CLI
        from levox.cli import main as cli_main
        cli_main()
    except ImportError as e:
        # If CLI is not available, show error and version info
        error_msg = f"Error importing CLI: {e}"
        print(error_msg)
        print_version_info()
        sys.exit(1)

def print_version_info():
    """Print version information."""
    features = get_features()
    
    print(f"Levox v{VERSION} ({BUILD_DATE})")
    print(f"Running on {SYSTEM_INFO}")
    print("\nFeatures:")
    for feature in features:
        print(f"- {feature}")
        
    print("\nBenchmark Data:")
    try:
        benchmark = get_benchmark_results() if get_benchmark_results else FALLBACK_BENCHMARK_DATA
        
        print(f"- Test dataset: {benchmark['name']}")
        print(f"- Files scanned: {benchmark['files_scanned']}")
        print(f"- Lines of code: {benchmark['lines_scanned']}")
        print(f"- Scan time: {benchmark['scan_time']:.2f}s")
        print(f"- Issues found: {benchmark['issues_found']}")
        
        # Show accuracy metrics if available
        if 'true_positives' in benchmark and 'false_positives' in benchmark:
            print(f"- True positives: {benchmark['true_positives']}")
            print(f"- False positives: {benchmark['false_positives']}")
            
        # Calculate and display precision if possible
        if 'true_positives' in benchmark and 'issues_found' in benchmark and benchmark['issues_found'] > 0:
            precision = benchmark['true_positives'] / benchmark['issues_found']
            print(f"- Precision: {precision:.2f}")
            
        # Show accuracy if available
        if 'accuracy' in benchmark:
            print(f"- Accuracy: {benchmark['accuracy']:.2f}")
            
        # Add meta-learning info
        try:
            ml_engine = MetaLearningEngine()
            ml_stats = ml_engine.get_learning_stats()
            if ml_stats.get('feedback_count', 0) > 0:
                print("\nMeta-Learning Status:")
                print(f"- Feedback records: {ml_stats.get('feedback_count', 0)}")
                print(f"- Issue types analyzed: {len(ml_stats.get('issue_types', []))}")
                
                # Total false positives/negatives
                fp_total = sum(ml_stats.get('false_positive_counts', {}).values())
                fn_total = sum(ml_stats.get('false_negative_counts', {}).values())
                print(f"- False positives identified: {fp_total}")
                print(f"- False negatives identified: {fn_total}")
        except Exception:
            # Meta-learning not available or error
            pass
            
    except Exception as e:
        print(f"Error loading benchmark data: {e}")

if __name__ == "__main__":
    # If run directly, start the CLI
    main() 